Three plots are available: 1) Dunn-Smyth residuals for species richness against the expected species richness, 2) a Normal Q-Q plot of those residuals, and 3) observed against predicted species richness, with a one-to-one line and, if the predictSR object includes one, the confidence interval of the prediction.

# S3 method for class 'predictSR.gllvm'
plot(
  x,
  object = NULL,
  which = 1:3,
  caption = c("Residuals vs fitted", "Normal Q-Q", "Observed vs fitted"),
  ...
)

Arguments

x

an object of class 'predictSR.gllvm'.

object

an object of class 'gllvm', defaults to NULL. Only used if x is NULL, in which case "predictSR.gllvm" is called on object first.

which

if a subset of the plots is required, specify a subset of the numbers 1:3, see the description above.

caption

captions to appear above the plots.

...

additional graphical arguments.

Details

plot.predictSR.gllvm is used for diagnostics of predicted species richness. Dunn-Smyth residuals (randomized quantile residuals) (Dunn and Smyth, 1996) for species richness are used in the first two plots, see "residuals.predictSR.gllvm".

References

Dunn, P. K., and Smyth, G. K. (1996). Randomized quantile residuals. Journal of Computational and Graphical Statistics, 5, 236-244.

Author

Bert van der Veen