residuals.predictSR.gllvm: Dunn-Smyth residuals for species richness from a gllvm object

View source: R/predictSR.gllvm.R

residuals.predictSR.gllvmR Documentation

Dunn-Smyth residuals for species richness from a gllvm object

Description

Calculates Dunn-Smyth residuals for species richness.

Usage

## S3 method for class 'predictSR.gllvm'
residuals(object, model, ...)

Arguments

object

object returned by "predictSR.gllvm"

model

an object of class 'gllvm'.

...

not used.

Details

See "residuals.gllvm" for details.

Value

A list of length 2 with 1) the fitted and 2) the dunn-smyth residuals.

Author(s)

Bert van der Veen

See Also

predict.gllvm, predictSR.gllvm, residuals.gllvm


gllvm documentation built on May 10, 2026, 5:06 p.m.