R/predictSR.gllvm.R
plot.predictSR.gllvm.RdThree plots are available: 1) Dunn-Smyth residuals for species richness against the expected species richness, 2) a Normal Q-Q plot of those residuals, and 3) observed against predicted species richness, with a one-to-one line and, if the predictSR object includes one, the confidence interval of the prediction.
an object of class 'predictSR.gllvm'.
an object of class 'gllvm', defaults to NULL. Only used if x is NULL, in which case "predictSR.gllvm" is called on object first.
if a subset of the plots is required, specify a subset of the numbers 1:3, see the description above.
captions to appear above the plots.
additional graphical arguments.
plot.predictSR.gllvm is used for diagnostics of predicted species richness. Dunn-Smyth residuals (randomized quantile residuals) (Dunn and Smyth, 1996) for species richness are used in the first two plots, see "residuals.predictSR.gllvm".
Dunn, P. K., and Smyth, G. K. (1996). Randomized quantile residuals. Journal of Computational and Graphical Statistics, 5, 236-244.